@@ -1,11 +1,4 @@
-# -*- coding: utf-8 -*-
-#
-# constants.py
-#
-# Copyright (C) 2012, 2013 Steve Canny scanny@cisco.com
-#
-# This module is part of python-pptx and is released under
-# the MIT License: http://www.opensource.org/licenses/mit-license.php
+# encoding: utf-8
 
 """
 Constant values modeled after those in the MS Office API.
@@ -204,6 +197,8 @@ class MSO_AUTO_SHAPE_TYPE(object):
     VERTICAL_SCROLL = 101
     WAVE = 103
 
+MSO_SHAPE = MSO_AUTO_SHAPE_TYPE
+
 
 class MSO(object):
     """
